package com.feedback.demo.controllers;

import com.feedback.demo.dto.FeedBackSettingsDTO;
import com.feedback.demo.entities.FeedBackSettings;
import com.feedback.demo.repositories.UserRepository;
import com.feedback.demo.service.FeedBackSettingsService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@RestController
@RequestMapping("/feedback-settings")
@Tag(name = "Feed Back Settings")
public class FeedBackSettingsController {
    @Autowired
    private FeedBackSettingsService feedBackSettingsService;
    @Autowired
    private UserRepository userRepository;

    @Operation(description = "Update FeedBack settings", responses = {
            @ApiResponse(content = @Content(array = @ArraySchema(schema = @Schema(implementation = FeedBackSettings.class))), responseCode = "200")
    })
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "Thành công"),
            @ApiResponse(responseCode = "404", description = "Không tìm thấy"),
            @ApiResponse(responseCode = "401", description = "Chưa xác thực"),
            @ApiResponse(responseCode = "403", description = "Truy cập bị cấm"),
    })
    @PostMapping("/update")
    public ResponseEntity<FeedBackSettingsDTO> addFeedbackSettings(@Valid @RequestBody FeedBackSettingsDTO feedBackSettingsDTO){
        return ResponseEntity.ok(feedBackSettingsService.updateSettings(feedBackSettingsDTO));
    }
    @Operation(description = "Get FeedBack settings", responses = {
            @ApiResponse(content = @Content(array = @ArraySchema(schema = @Schema(implementation = FeedBackSettings.class))), responseCode = "200")
    })
    @GetMapping("/")
    public ResponseEntity<FeedBackSettingsDTO> getFeedbackSettings(){
        return ResponseEntity.ok(feedBackSettingsService.getFeedbackSettings());
    }
}
